@@ -74,7 +74,7 @@ class R3sponse(object):
 	# parameter functions.
 	def get_request_parameter(self, request, identifier):
 		response = self.default_response()
-		if request.POST
+		if request.POST:
 			variable = request.POST.get(identifier)
 		else:
 			variable = request.GET.get(identifier)
